#!/bin/bash
#
# *******************************************************************************
#  Dieses Script bindet eine (und nur genau eine) LogicBox als /dev/ttyUSB0 ein.
#  Es muss als Root aufgerufen werden, nachdem die LogicBox an Strom und eine
#  USB-Buchse angeschlossen wurde.
#  Moeglicherweise werden USB-Massenspeicher und evtl. auch andere USB-Geraete
#  nach den Ausfuehren dieses Scripts nicht mehr erkannt. Der Befehl
#  "sudo modprobe usb-storage" bzw. ein Neustart koennte Abhilfe schaffen.
#
#                                                 15.10.2008 by Peter Augenstein
# *******************************************************************************
#
LC_ALL=C

echo "Searching for LogicBox..."
usbID=`lsusb | grep -i -s "Future Technology Devices" 2> /dev/null | tail -n 1 2> /dev/null | awk '{printf "%s",$6}' 2> /dev/null`
vendorID=${usbID%:*}
productID=${usbID#*:}

if [ ${#vendorID} != "4" ]; then
  echo "LogicBox NOT found!"
  exit
fi

if [ ${#productID} != "4" ]; then
  echo "LogicBox NOT found!"
  exit
fi

echo "LogicBox found (vendor=${vendorID}, product=${productID})"

echo "Removing kernel modules usb-storage and usbserial..."
rmmod usb-storage 2> /dev/null
rmmod usbserial 2> /dev/null
sleep 2s
echo "Installing kernel module usbserial for LogicBox..."
modprobe usbserial vendor=0x${vendorID} product=0x${productID}
sleep 3s
echo "Setting /dev/ttyUSB0 writeable..."
chmod a+rw /dev/ttyUSB0
echo ""
ls -l /dev/ttyUSB*
echo "DONE."

